@@ -9,6 +9,7 @@ SEXP R_dgeev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 	int n = INTEGER(N)[0], total_length;
 	SEXP T;
 	char CS_JOBVL = CHARPT(JOBVL, 0)[0], CS_JOBVR = CHARPT(JOBVR, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(T = allocMatrix(REALSXP, n, n));
@@ -19,36 +20,22 @@ SEXP R_dgeev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVL == 'V' && CS_JOBVR == 'V'){
-		F77_CALL(dgeev)("V", "V",
-			INTEGER(N), REAL(T), INTEGER(LDA),
-			REAL(WR), REAL(WI),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'V'){
-		F77_CALL(dgeev)("N", "V",
-			INTEGER(N), REAL(T), INTEGER(LDA),
-			REAL(WR), REAL(WI),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 1;
 	} else if(CS_JOBVL == 'V' && CS_JOBVR == 'N'){
-		F77_CALL(dgeev)("V", "N",
-			INTEGER(N), REAL(T), INTEGER(LDA),
-			REAL(WR), REAL(WI),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 2;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'N'){
-		F77_CALL(dgeev)("N", "N",
-			INTEGER(N), REAL(T), INTEGER(LDA),
-			REAL(WR), REAL(WI),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 3;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wdgeev)(&CF_wrap,
+		INTEGER(N), REAL(T), INTEGER(LDA),
+		REAL(WR), REAL(WI),
+		REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
+		REAL(WORK), INTEGER(LWORK),
+		INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(1);
