@@ -14,6 +14,7 @@ SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 	int n = INTEGER(N)[0], total_length;
 	SEXP RET, RET_NAMES, T;
 	char CS_JOBVS = CHARPT(JOBVS, 0)[0], CS_SORT = CHARPT(SORT, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(RET = allocVector(VECSXP, 1));
@@ -30,20 +31,17 @@ SEXP R_zgees(SEXP JOBVS, SEXP SORT, SEXP SELECT, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVS == 'V' && CS_SORT == 'N'){
-		F77_CALL(zgees)("V", "N",
-			fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
-			COMPLEX(WORK), INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVS == 'N' && CS_SORT == 'N'){
-		F77_CALL(zgees)("N", "N",
-			fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
-			COMPLEX(WORK), INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		CF_wrap = 1;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wzgees)(&CF_wrap,
+		fake_select, INTEGER(N), COMPLEX(T), INTEGER(LDA),
+		INTEGER(SDIM), COMPLEX(W), COMPLEX(VS), INTEGER(LDVS),
+		COMPLEX(WORK), INTEGER(LWORK),
+		REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(3);
