@@ -10,6 +10,7 @@ SEXP R_zgeev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 	int n = INTEGER(N)[0], total_length;
 	SEXP T;
 	char CS_JOBVL = CHARPT(JOBVL, 0)[0], CS_JOBVR = CHARPT(JOBVR, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(T = allocMatrix(CPLXSXP, n, n));
@@ -20,36 +21,22 @@ SEXP R_zgeev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVL == 'V' && CS_JOBVR == 'V'){
-		F77_CALL(zgeev)("V", "V",
-			INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			COMPLEX(W), COMPLEX(VL), INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'V'){
-		F77_CALL(zgeev)("N", "V",
-			INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			COMPLEX(W), COMPLEX(VL), INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 1;
 	} else if(CS_JOBVL == 'V' && CS_JOBVR == 'N'){
-		F77_CALL(zgeev)("V", "N",
-			INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			COMPLEX(W), COMPLEX(VL), INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 2;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'N'){
-		F77_CALL(zgeev)("N", "N",
-			INTEGER(N), COMPLEX(T), INTEGER(LDA),
-			COMPLEX(W), COMPLEX(VL), INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 3;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wzgeev)(&CF_wrap,
+		INTEGER(N), COMPLEX(T), INTEGER(LDA),
+		COMPLEX(W), COMPLEX(VL), INTEGER(LDVL),
+		COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
+		INTEGER(LWORK),
+		REAL(RWORK), INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(1);
