@@ -15,6 +15,7 @@ SEXP R_zgges(SEXP JOBVSL, SEXP JOBVSR, SEXP SORT, SEXP SELCTG, SEXP N,
 	SEXP RET, RET_NAMES, S, T;
 	char CS_JOBVSL = CHARPT(JOBVSL, 0)[0], CS_JOBVSR = CHARPT(JOBVSR, 0)[0],
 		CS_SORT = CHARPT(SORT, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(RET = allocVector(VECSXP, 2));
@@ -35,44 +36,24 @@ SEXP R_zgges(SEXP JOBVSL, SEXP JOBVSR, SEXP SORT, SEXP SELCTG, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVSL == 'V' && CS_JOBVSR == 'V' && CS_SORT == 'N'){
-		F77_CALL(zgges)("V", "V", "N",
-			fake_selctg, INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB), INTEGER(SDIM),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VSL),
-			INTEGER(LDVSL),
-			COMPLEX(VSR), INTEGER(LDVSR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVSL == 'N' && CS_JOBVSR == 'V' && CS_SORT == 'N'){
-		F77_CALL(zgges)("N", "V", "N",
-			fake_selctg, INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB), INTEGER(SDIM),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VSL),
-			INTEGER(LDVSL),
-			COMPLEX(VSR), INTEGER(LDVSR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		CF_wrap = 1;
 	} else if(CS_JOBVSL == 'V' && CS_JOBVSR == 'N' && CS_SORT == 'N'){
-		F77_CALL(zgges)("V", "N", "N",
-			fake_selctg, INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB), INTEGER(SDIM),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VSL),
-			INTEGER(LDVSL),
-			COMPLEX(VSR), INTEGER(LDVSR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
-	} else if(CS_JOBVSL == 'N' && CS_JOBVSR == 'N' && CS_SORT == 'N'){
-		F77_CALL(zgges)("N", "N", "N",
-			fake_selctg, INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB), INTEGER(SDIM),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VSL),
-			INTEGER(LDVSL),
-			COMPLEX(VSR), INTEGER(LDVSR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
+		CF_wrap = 2;
+        } else if(CS_JOBVSL == 'N' && CS_JOBVSR == 'N' && CS_SORT == 'N'){
+		CF_wrap = 3;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wzgges)(&CF_wrap,
+		fake_selctg, INTEGER(N), COMPLEX(S), INTEGER(LDA),
+		COMPLEX(T), INTEGER(LDB), INTEGER(SDIM),
+		COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VSL),
+		INTEGER(LDVSL),
+		COMPLEX(VSR), INTEGER(LDVSR), COMPLEX(WORK),
+		INTEGER(LWORK),
+		REAL(RWORK), INTEGER(BWORK), INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(4);
